@@ -85,7 +85,7 @@ def create_hpo(http_host:str, exp_name: str="", team_name: str="", hpo_config: D
     rsp = post(url, data)
     logger.debug("create_hpo() response : " + rsp["message"])
     return rsp
-    # get_jwt_key()
+
 
 
 def finish(http_host: str ,data: Dict) -> Dict:
@@ -108,5 +108,5 @@ def get_headers():
         "Content-Type": "application/json",
     }
     if jwt_key:
-        headers["Authorization"] = jwt_key
+        headers["Authorization"] = f"Bearer {jwt_key}"
     return headers
